@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/config_f.h,v 3.21 1998/10/25 15:09:45 christos Exp $ */
+/* $Header: /src/pub/tcsh/config_f.h,v 3.22 1999/05/11 13:07:42 christos Exp $ */
 /*
  * config_f.h -- configure various defines for tcsh
  *
@@ -170,6 +170,12 @@
  */
 #define COLOR_LS_F
 
+/*
+ * COLORCAT Do you want to colorful message ?
+ *
+ */
+#undef COLORCAT
+
 /*
  * RCSID	This defines if we want rcs strings in the binary or not
  *
