@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/sh.func.c,v 3.78 1998/10/25 15:10:12 christos Exp $ */
+/* $Header: /src/pub/tcsh/sh.func.c,v 3.85 1999/08/16 20:05:49 christos Exp $ */
 /*
  * sh.func.c: csh builtin functions
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.func.c,v 3.78 1998/10/25 15:10:12 christos Exp $")
+RCSID("$Id: sh.func.c,v 3.85 1999/08/16 20:05:49 christos Exp $")
 
 #include "ed.h"
 #include "tw.h"
@@ -78,6 +78,14 @@ isbfunc(t)
     static struct biltins foregnd = {"%job", dofg1, 0, 0};
     static struct biltins backgnd = {"%job &", dobg1, 0, 0};
 
+    /*
+     * We never match a builtin that has quoted the first
+     * character; this has been the traditional way to escape 
+     * builtin commands.
+     */
+    if (*cp & QUOTE)
+	return NULL;
+
     if (*cp != ':' && lastchr(cp) == ':') {
 	label.bname = short2str(cp);
 	return (&label);
@@ -1160,12 +1168,22 @@ xecho(sep, v)
 	while ((c = *cp++) != 0) {
 	    if ((echo_style & SYSV_ECHO) != 0 && c == '\\') {
 		switch (c = *cp++) {
+		case 'a':
+		    c = '\a';
+		    break;
 		case 'b':
 		    c = '\b';
 		    break;
 		case 'c':
 		    nonl = 1;
 		    goto done;
+		case 'e':
+#if 0			/* Windows does not understand \e */
+		    c = '\e';
+#else
+		    c = '\033';
+#endif
+		    break;
 		case 'f':
 		    c = '\f';
 		    break;
@@ -1366,6 +1384,9 @@ dosetenv(v, c)
 
     if (eq(vp, STRNOREBIND)) {
 	NoNLSRebind = 1;
+	MapsAreInited = 0;
+	NLSMapsAreInited = 0;
+	ed_InitMaps();
 	xfree((ptr_t) lp);
 	return;
     }
@@ -1499,8 +1520,12 @@ dounsetenv(v, c)
 		 */
 		Unsetenv(name);
 
-		if (eq(name, STRNOREBIND))
+		if (eq(name, STRNOREBIND)) {
 		    NoNLSRebind = 0;
+		    MapsAreInited = 0;
+		    NLSMapsAreInited = 0;
+		    ed_InitMaps();
+		}
 #ifdef apollo
 		else if (eq(name, STRSYSTYPE))
 		    dohash(NULL, NULL);
@@ -1596,7 +1621,12 @@ tsetenv(name, val)
 	nt_set_env(name,val);
 #endif /* WINNT */
     for (; *ep; ep++) {
+#ifdef WINNT
+	for (cp = name, dp = *ep; *cp && Tolower(*cp & TRIM) == Tolower(*dp);
+				cp++, dp++)
+#else
 	for (cp = name, dp = *ep; *cp && (*cp & TRIM) == *dp; cp++, dp++)
+#endif /* WINNT */
 	    continue;
 	if (*cp != 0 || *dp != '=')
 	    continue;
@@ -1692,7 +1722,7 @@ doumask(v, c)
 #  if defined(BSD4_4) && !defined(__386BSD__)
     typedef quad_t RLIM_TYPE;
 #  else
-#   if defined(SOLARIS2)
+#   if defined(SOLARIS2) || (defined(sgi) && SYSVREL > 3)
      typedef rlim_t RLIM_TYPE;
 #   else
 #    if defined(_SX)
@@ -1700,7 +1730,7 @@ doumask(v, c)
 #    else /* _SX */
       typedef unsigned long RLIM_TYPE;
 #    endif /* _SX */
-#   endif /* SOLARIS2 */
+#   endif /* SOLARIS2 || (sgi && SYSVREL > 3) */
 #  endif /* BSD4_4 && !__386BSD__  */
 # endif /* BSDLIMIT */
 
@@ -2017,9 +2047,7 @@ plim(lp, hard)
 	limit -= 0x20000000;
 #  endif /* aiws */
 # else /* BSDLIMIT */
-xprintf("Getting limit %s(%d)\n", lp->limname,lp->limconst);
     (void) getrlimit(lp->limconst, &rlim);
-xprintf("Hard: %lld, Soft: %lld\n", rlim.rlim_max, rlim.rlim_cur);
     limit = hard ? rlim.rlim_max : rlim.rlim_cur;
 # endif /* BSDLIMIT */
 
@@ -2044,12 +2072,7 @@ xprintf("Hard: %lld, Soft: %lld\n", rlim.rlim_max, rlim.rlim_cur);
 	psecs((long) limit);
     else
 # endif /* RLIMIT_CPU */
-# if defined(_SX)
-	xprintf("(%ld , %ld)", rlim.rlim_max, rlim.rlim_cur);
-	xprintf("%ld / %d %s", limit,  div, lp->limscale);
-#else	/* _SX */
 	xprintf("%ld %s", (long) (limit / div), lp->limscale);
-#endif	/* _SX */
     xputchar('\n');
 }
 
