@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/tc.func.c,v 3.81 1998/10/25 15:10:32 christos Exp $ */
+/* $Header: /src/pub/tcsh/tc.func.c,v 3.87 1999/08/14 21:24:13 christos Exp $ */
 /*
  * tc.func.c: New tcsh builtins.
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: tc.func.c,v 3.81 1998/10/25 15:10:32 christos Exp $")
+RCSID("$Id: tc.func.c,v 3.87 1999/08/14 21:24:13 christos Exp $")
 
 #include "ed.h"
 #include "ed.defns.h"		/* for the function names */
@@ -63,12 +63,12 @@ extern int do_logout;
 extern time_t t_period;
 extern int just_signaled;
 static bool precmd_active = 0;
+static bool postcmd_active = 0;
 static bool periodic_active = 0;
 static bool cwdcmd_active = 0;	/* PWP: for cwd_cmd */
 static bool beepcmd_active = 0;
 static signalfun_t alm_fun = NULL;
 
-static	void	 Reverse	__P((Char *));
 static	void	 auto_logout	__P((int));
 static	char	*xgetpass	__P((char *));
 static	void	 auto_lock	__P((int));
@@ -171,37 +171,48 @@ sprlex(buf, bufsiz, sp0)
     return (buf);
 }
 
-void
-Itoa(n, s)			/* convert n to characters in s */
-    int     n;
-    Char   *s;
+
+Char *
+Itoa(n, s, min_digits, attributes)
+    int n;
+    Char *s;
+    int min_digits, attributes;
 {
-    int     i, sign;
+    /*
+     * The array size here is derived from
+     *	log8(UINT_MAX)
+     * which is guaranteed to be enough for a decimal
+     * representation.  We add 1 because integer divide
+     * rounds down.
+     */
+#ifndef CHAR_BIT
+# define CHAR_BIT 8
+#endif
+    Char buf[CHAR_BIT * sizeof(int) / 3 + 1];
+    Char *p;
+    unsigned int un;	/* handle most negative # too */
+    int pad = (min_digits != 0);
 
-    if ((sign = n) < 0)		/* record sign */
-	n = -n;
-    i = 0;
-    do {
-	s[i++] = n % 10 + '0';
-    } while ((n /= 10) > 0);
-    if (sign < 0)
-	s[i++] = '-';
-    s[i] = '\0';
-    Reverse(s);
-}
+    if (sizeof(buf) - 1 < min_digits)
+	min_digits = sizeof(buf) - 1;
 
-static void
-Reverse(s)
-    Char   *s;
-{
-    Char   c;
-    int     i, j;
-
-    for (i = 0, j = (int) Strlen(s) - 1; i < j; i++, j--) {
-	c = s[i];
-	s[i] = s[j];
-	s[j] = c;
+    un = n;
+    if (n < 0) {
+	un = -n;
+	*s++ = '-';
     }
+
+    p = buf;
+    do {
+	*p++ = un % 10 + '0';
+	un /= 10;
+    } while ((pad && --min_digits > 0) || un != 0);
+
+    while (p > buf)
+	*s++ = *--p | attributes;
+
+    *s = '\0';
+    return s;
 }
 
 
@@ -345,9 +356,6 @@ dolist(v, c)
     }
     else {
 	Char   *dp, *tmp, buf[MAXPATHLEN];
-#ifdef WINNT
-	int is_unc = 0;
-#endif /* WINNT */
 
 	for (k = 0, i = 0; v[k] != NULL; k++) {
 	    tmp = dnormalize(v[k], symlinks == SYM_IGNORE);
@@ -357,17 +365,7 @@ dolist(v, c)
 		if (dp != &tmp[1])
 #endif /* apollo */
 		*dp = '\0';
-#ifdef WINNT
-		if ((((tmp[0] & CHAR) == '/') || ((tmp[0] & CHAR) == '\\')) &&  
-		    (((tmp[1] & CHAR) == '/') || ((tmp[1] & CHAR) == '\\')))
-		    is_unc = 1;
-#endif /* WINNT */
-	    if (
-#ifdef WINNT
-		((char)tmp[1] != ':') &&
-		(!is_unc) &&
-#endif /* WINNT */
-		stat(short2str(tmp), &st) == -1) {
+		if (stat(short2str(tmp), &st) == -1) {
 		if (k != i) {
 		    if (i != 0)
 			xputchar('\n');
@@ -376,12 +374,7 @@ dolist(v, c)
 		xprintf("%S: %s.\n", tmp, strerror(errno));
 		i = k + 1;
 	    }
-	    else if (
-#ifdef WINNT
-		((char)tmp[1] == ':') ||
-		(is_unc) ||
-#endif /* WINNT */
-		S_ISDIR(st.st_mode)) {
+	    else if (S_ISDIR(st.st_mode)) {
 		Char   *cp;
 
 		if (k != i) {
@@ -900,6 +893,33 @@ leave:
 #endif /* BSDSIGS */
 }
 
+void
+postcmd()
+{
+#ifdef BSDSIGS
+    sigmask_t omask;
+
+    omask = sigblock(sigmask(SIGINT));
+#else /* !BSDSIGS */
+    (void) sighold(SIGINT);
+#endif /* BSDSIGS */
+    if (postcmd_active) {	/* an error must have been caught */
+	aliasrun(2, STRunalias, STRpostcmd);
+	xprintf(CGETS(22, 3, "Faulty alias 'postcmd' removed.\n"));
+	goto leave;
+    }
+    postcmd_active = 1;
+    if (!whyles && adrof1(STRpostcmd, &aliases))
+	aliasrun(1, STRpostcmd, NULL);
+leave:
+    postcmd_active = 0;
+#ifdef BSDSIGS
+    (void) sigsetmask(omask);
+#else /* !BSDSIGS */
+    (void) sigrelse(SIGINT);
+#endif /* BSDSIGS */
+}
+
 /*
  * Paul Placeway  11/24/87  Added cwd_cmd by hacking precmd() into
  * submission...  Run every time $cwd is set (after it is set).  Useful
@@ -990,8 +1010,10 @@ period_cmd()
     periodic_active = 1;
     if (!whyles && adrof1(STRperiodic, &aliases)) {
 	vp = varval(STRtperiod);
-	if (vp == STRNULL)
-	    return;
+	if (vp == STRNULL) {
+	    aliasrun(1, STRperiodic, NULL);
+	    goto leave;
+	}
 	interval = getn(vp);
 	(void) time(&t);
 	if (t - t_period >= interval * 60) {
@@ -1076,6 +1098,8 @@ aliasrun(cnt, s1, s2)
 	 */
 	if (precmd_active)
 	    precmd();
+	if (postcmd_active)
+	    postcmd();
 #ifdef notdef
 	/*
 	 * XXX: On the other hand, just interrupting them causes an error too.
@@ -1746,7 +1770,7 @@ shlvl(val)
 	else {
 	    Char    buff[BUFSIZE];
 
-	    Itoa(val, buff);
+	    (void) Itoa(val, buff, 0, 0);
 	    set(STRshlvl, Strsave(buff), VAR_READWRITE);
 	    tsetenv(STRKSHLVL, buff);
 	}
